#!/usr/bin/env python
#==============================================================================
# Copyright and license info is available in the LICENSE file included with
# the Server Deployment Package (SDP), and also available online:
# https://swarm.workshop.perforce.com/projects/perforce-software-sdp/view/main/LICENSE
#------------------------------------------------------------------------------

"""
Usage:
       SetCFOpts form-out change "python /p4/common/bin/triggers/SetCFOptions.py %formfile%"

This script is designed to run as a form out trigger on a change form.  It
changes the 'Type:' field from 'public' to 'restricted', thus making
changelist metadata (description, etc.) available only to users who have
at least list access on files affected by any given changelist.  It
requires a p4d 2010.2+ server.

This operates only on new changelist forms.

Side Effects: This might have an impact on performance of 'p4 changes'
commands.  It is intended for environments that value security of changelist-
related metadata.
"""

import os
import re
import string
import sys
import random
import shutil

tempfile = str(random.random())
input = open(sys.argv[1], "r")
output = open(tempfile, "w")

for line in input.readlines():
    if re.search ("^Change:", line):
        if not re.search ("^Change:\tnew", line):
            input.close()
            output.close()
            os.remove(tempfile)
            sys.exit(0)
    if re.search ("^Description:", line):
        line = re.sub ("^Description:", "Type:\trestricted\n\nDescription:", line)
    output.write(line)

input.close()
output.close()
os.remove(sys.argv[1])
shutil.copy(tempfile, sys.argv[1])
os.remove(tempfile)

sys.exit(0)
