#!/bin/bash
set -u

# Get EBS volumes with Name tag of <host>-root and # <host>-hxdepots,
# e.g. perforce-01-root and perforce-01-hxdepots.  Take snapshots, and
# tag them with the current journal counter.

function msg () { echo -e "$*"; }
function errmsg () { msg "\\nError: ${1:-Unknown Error}\\n"; ExitCode=1; }
function bail () { errmsg "${1:-Unknown Error}"; exit "${2:-1}"; }

declare ThisScript="${0##*/}"
declare Version="1.0.2"
declare ThisHost=$(hostname -s)
declare VolumeBaseName=
declare VolumeName=
declare VolumeId=
declare -i ExitCode=0

msg "Started ${0##*/} v$Version at $(date)."

for VolumeBaseName in root hxdepots; do
   VolumeName="${ThisHost}-${VolumeBaseName}"
   VolumeId=$(aws ec2 describe-volumes --filters Name=tag:Name,Values=$VolumeName --query 'Volumes[*].{ID:VolumeId}')

   if [[ -z "$VolumeId" ]]; then
      errmsg "Could not determine VolumeId for $VolumeName. Skipping it."
      continue
   fi

   msg "Snapshotting volume $VolumeName [$VolumeId]."

   msg aws ec2 create-snapshot --description "Snaphot of $VolumeName on $(date)." --volume-id $VolumeId --tag-specifications "ResourceType=snapshot,Tags=[{Key=Host,Value=$ThisHost},{Key=Contents,Value=CheckpointsAndArchives}]"
   aws ec2 create-snapshot --description "Snaphot of $VolumeName on $(date)." --volume-id $VolumeId --tag-specifications "ResourceType=snapshot,Tags=[{Key=Host,Value=$ThisHost},{Key=Contents,Value=CheckpointsAndArchives}]" ||\
      errmsg "Failed to create snapshot for $VolumeName."
done

if [[ "$ExitCode" -eq 0 ]]; then
   msg "Processing completed OK."
else
   msg "Processing completed WITH ERRORS. Review the output above."
fi

exit $ExitCode
